@@ -168,7 +168,9 @@ gist_create_git <- function(files = NULL, description = "", public = TRUE,
   }
   
   # add files
-  ftoadd <- gsub(sprintf("%s/?|\\./", git@path), "", allfiles)
+  git2r_ver <- unclass(utils::packageVersion('git2r'))[[1]][2]
+  patttth <- if (git2r_ver >= 22) git$path else git@path
+  ftoadd <- gsub(sprintf("%s/?|\\./", patttth), "", allfiles)
   git2r::add(git, ftoadd)
   # commit files
   cm <- tryCatch(git2r::commit(git, message = "added files from gistr"), 
@@ -261,6 +263,7 @@ cgist <- function(description, public) {
                       )
                     ), auto_unbox = TRUE)
   )
+  stopstatus(res)
   jsonlite::fromJSON(httr::content(res, "text", encoding = "UTF-8"), FALSE)
 }
 
