@@ -6,9 +6,10 @@
 #' @return A data.frame or list of data.frame's
 #' @details For commits we return a single data.frame. For gists, we always 
 #' return a list so that we are returning data consistently, 
-#' regardless of variable return data. So you can always index to the main data.frame
-#' with gist metadata and file info by doing \code{result$data}, and likewise for 
-#' forks \code{result$forks} and history \code{result$history}
+#' regardless of variable return data. So you can always index to the main 
+#' data.frame with gist metadata and file info by doing \code{result$data}, 
+#' and likewise for  forks \code{result$forks} and history 
+#' \code{result$history}
 #' @examples \dontrun{
 #' # from a gist object
 #' x <- as.gist('f1403260eb92f5dfa7e1')
@@ -62,11 +63,13 @@ tabl.gist <- function(x, ...){
   files <- lappdf(others$files, "files")
   files_n <- NROW(files)
   
-  singles <- move_cols(data.frame(null2na(x[ names(x) %in% snames ]), stringsAsFactors = FALSE), "id")
+  singles <- move_cols(data.frame(null2na(x[ names(x) %in% snames ]), 
+                                  stringsAsFactors = FALSE), "id")
   singles <- repeat_rows(singles, files_n)
   
   owner <- data.frame(others$owner, stringsAsFactors = FALSE)
-  owner <- if (NROW(owner) == 0) owner else setNames(owner, paste0("owner_", names(owner)))
+  owner <- if (NROW(owner) == 0) owner else 
+    stats::setNames(owner, paste0("owner_", names(owner)))
   owner <- repeat_rows(owner, files_n)
   
   one <- dplyr::as_data_frame(cbind_fill(singles, files, owner, as_df = TRUE))
@@ -88,8 +91,8 @@ repeat_rows <- function(x, n) {
 #' @export
 #' @rdname tabl
 tabl_data <- function(x) {
-  stopifnot(is(x, "list"))
-  suppressWarnings(dplyr::rbind_all(lapply(x, "[[", "data")))
+  stopifnot(inherits(x, "list"))
+  suppressWarnings(dplyr::bind_rows(lapply(x, "[[", "data")))
 }
 
 #' @export
@@ -98,20 +101,21 @@ tabl.list <- function(x, ...) {
     x <- unlist(x, recursive = FALSE)
   }
   res <- lapply(x, tabl)
-  if (is(x[[1]], "commit")) {
-    suppressWarnings(rbind_all(res))
+  if (inherits(x[[1]], "commit")) {
+    suppressWarnings(dplyr::bind_rows(res))
   } else {
     res
   }
-  # suppressWarnings(rbind_all(lapply(x, tabl)))
 }
 
 #' @export
 tabl.commit <- function(x, ...){
   as_data_frame(move_cols(
-    do.call("cbind", gist_compact(list(null2na(x$user), 
-                          flatten(data.frame(null2na(pop(unclass(x), "user")), 
-                                             stringsAsFactors = FALSE))))), "id"))
+    do.call("cbind", 
+            gist_compact(
+              list(null2na(x$user), 
+                   flatten(data.frame(null2na(pop(unclass(x), "user")), 
+                                      stringsAsFactors = FALSE))))), "id"))
 }
 
 snames <- c("url","forks_url", "commits_url", "id", "git_pull_url",
@@ -119,14 +123,14 @@ snames <- c("url","forks_url", "commits_url", "id", "git_pull_url",
             "updated_at", "description", "comments", "user", "comments_url")
 
 lappdf <- function(x, prefix = NULL) {
-  tmp <- data.frame(rbind_all(lapply(x, function(z) {
+  tmp <- data.frame(dplyr::bind_rows(lapply(x, function(z) {
     data.frame(null2na(z), stringsAsFactors = FALSE)
   })), stringsAsFactors = FALSE)
   if (!is.null(prefix)) {
     if (NROW(tmp) == 0) {
       tmp
     } else {
-      setNames( tmp, paste0(prefix, "_", names(tmp)) )
+      stats::setNames( tmp, paste0(prefix, "_", names(tmp)) )
     }
   } else {
     tmp
@@ -160,7 +164,8 @@ cbind_fill <- function(..., as_df = FALSE) {
 
 move_cols <- function(x, y) {
   if (y %in% names(x)) {
-    x[ c(y, names(x)[-sapply(y, function(z) grep(paste0('\\b', z, '\\b'), names(x)))]) ]
+    x[ c(y, names(x)[-sapply(y, function(z) grep(paste0('\\b', z, '\\b'),
+                                                 names(x)))]) ]
   } else {
     x
   }
