@@ -1,7 +1,8 @@
 context("gist_create_git")
 
-test_that("gist_create_git works xxx", {
+test_that("gist_create_git works", {
   skip_on_cran()
+  skip_on_travis()
   
   unlink("~/gitgist", recursive = TRUE)
   dir.create("~/gitgist")
